/* Copyright(C) 2005 Stefan Siegl <stesie@brokenpipe.de>
 * taxbird - free program to interface with German IRO's Elster/Coala
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef TAXBIRD_DIALOG_H
#define TAXBIRD_DIALOG_H

#include <gtk/gtk.h>

/* display a common error dialog with the given message (in modal mode) */
void taxbird_dialog_error(GtkWidget *parent, const char *message);

/* display a common info dialog with the given message (in modal mode) */
void taxbird_dialog_info(GtkWidget *parent, const char *message);

/* display a yes/no/cancel dialog with the given message (in modal mode) */
int taxbird_dialog_yes_no_cancel(GtkWidget *parent, const char *message);

#endif /* TAXBIRD_DIALOG_H */
